Scales
Dynamic SCALE Serialization using scale-info type information.
Re-exports
Modules
Structs
- Cursor
- A zero-copy cursor over SCALE-encoded bytes that yields
Values while advancing through the data. - Field
Iter - Iterator over named fields of a SCALE-encoded struct.
- SeqIter
- Iterator over elements of a SCALE-encoded sequence.
- Serializer
- A serializer that encodes types to SCALE with the option to coerce the output to an equivalent representation given by some type information.
- Tuple
Iter - Iterator over elements of a SCALE-encoded tuple.
- Value
- A container for SCALE encoded data that can serialize types directly with the help of a type registry and without using an intermediate representation.
Enums
- Json
Value - Represents any valid JSON value.
Functions
- from_
text - Parse a text-encoded string back into SCALE bytes, guided by the type registry.
- to_
bytes - SCALE-encode a value into an existing buffer.
- to_
bytes_ from_ iter - SCALE-encode a JSON-like key-value iterator into a buffer using type info.
- to_
bytes_ with_ info - SCALE-encode a value into a buffer, using type info to coerce representations.
- to_text
- Format a
Valueas a compact, URL-safe text string. - to_vec
- SCALE-encode a value into a new
Vec<u8>. - to_
vec_ from_ iter - Like
to_bytes_from_iterbut allocates and returns aVec<u8>. - to_
vec_ with_ info - SCALE-encode a value into a new
Vec<u8>, using type info to coerce representations.